/***** ms2dna.c ***************************************
 * Description: Convert haplotypes from Hudons's
 *   ms program to DNA sequence data.
 * Reference: Hudson, R. R. (2002). Generating
 *   samples under a Wright-Fisher neutral model 
 *   of genetic variation. Bioinformatics 18: 337-338.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Tue Aug 14 15:15:47 2007.
 * License: GNU General Public
 *****************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <unistd.h>
#include "eprintf.h"
#include "interface.h"
#include "stringUtil.h"
#include "sample.h"
#include "ran.h"

int runAnalysis(FILE *fpin, Args *args);

int main(int argc, char *argv[]){
  char *version;
  Args *args;
  FILE *fpin;
  int i;

  version = "1.12";
  setprogname2("ms2dna");
  args = getArgs(argc, argv);

  if(args->h == 1){
    printUsage(version);
    return 0; 
  }else if(args->e == 1){
    printUsage(version);
    return -1;
  }else if(args->p){
    printSplash(version);
    return 0;
  }

  if(args->numInputFiles == 0){
    fpin = stdin;
    runAnalysis(fpin, args);
  }else{
    for(i=0;i<args->numInputFiles;i++){
      fpin = efopen(args->inputFiles[i],"r");
      runAnalysis(fpin, args);
      fclose(fpin);
    }
  }
  free(args);
  free(progname());
  return 0;
}

int runAnalysis(FILE *fpin, Args *args){
  Sample *sample;
  FILE *fpout = stdout;

  sample = initializeSample(fpin, args);
  if(args->f == 1 && sample->npop != 2){
    printf("ERROR[ms2dna]: need two populations for ima output format\n");
    return -1;
  }
  if(args->f == -1)
    fprintf(fpout,"%d %d 1\n",sample->nsam*sample->howmany,sample->nsite);
  if(args->f == 1){
    fprintf(fpout,"Sample generated by ms2dna\n");
    fprintf(fpout,"#Comment\n");
    fprintf(fpout,"P1 P2\n");
    fprintf(fpout,"%d\n",sample->howmany);
  }
  while((sample = getSample()) != NULL){
    outputSample(fpout);
  }
  freeSample();
  return 0;
}
